4.2. umbra.components.addons.projectsExplorer.projectsExplorer — Umbra 1.0.8 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.8 documentation »
- 4. Api »

# 4.2. umbra.components.addons.projectsExplorer.projectsExplorer

projectsExplorer.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  This module defines the `ProjectsExplorer` Component Interface class and others helper objects.

Others:

## 4.2.1. Module Attributes

`umbra.components.addons.projectsExplorer.projectsExplorer.` `LOGGER`

`umbra.components.addons.projectsExplorer.projectsExplorer.` `COMPONENT_UI_FILE`

## 4.2.2. Classes

class `umbra.components.addons.projectsExplorer.projectsExplorer.` `ProjectsExplorer`(parent=None, name=None, *args, **kwargs)

  Bases: `manager.qwidgetComponent.QWidgetComponent`

  This class is the `sibl_gui.components.addons.projectsExplorer.projectsExplorer` Component Interface class.

  Parameters: | parent – Object parent. ( QObject ) name – Component name. ( String ) *args – Arguments. ( * ) **kwargs – Keywords arguments. ( ** )

  `dockArea`

    This method is the property for self.__dockArea attribute.

    Returns: | self.__dockArea. ( Integer )

  `engine`

    This method is the property for self.__engine attribute.

    Returns: | self.__engine. ( QObject )

  `settings`

    This method is the property for self.__settings attribute.

    Returns: | self.__settings. ( QSettings )

  `settingsSection`

    This method is the property for self.__settingsSection attribute.

    Returns: | self.__settingsSection. ( String )

  `scriptEditor`

    This method is the property for self.__scriptEditor attribute.

    Returns: | self.__scriptEditor. ( QWidget )

  `model`

    This method is the property for self.__model attribute.

    Returns: | self.__model. ( CollectionsModel )

  `view`

    This method is the property for self.__view attribute.

    Returns: | self.__view. ( QWidget )

  `delegate`

    This method is the property for self.__delegate attribute.

    Returns: | self.__delegate. ( QItemDelegate )

  `style`

    This method is the property for self.__style attribute.

    Returns: | self.__style. ( Style )

  `activate`(engine)

    This method activates the Component.

    Parameters: | engine – Engine to attach the Component to. ( QObject )
    Returns: | Method success. ( Boolean )

  `deactivate`()

    This method deactivates the Component.

    Returns: | Method success. ( Boolean )

  `initializeUi`()

    This method initializes the Component ui.

    Returns: | Method success. ( Boolean )

  `uninitializeUi`()

    This method uninitializes the Component ui.

    Returns: | Method success. ( Boolean )

  `addWidget`()

    This method adds the Component Widget to the engine.

    Returns: | Method success. ( Boolean )

  `removeWidget`()

    This method removes the Component Widget from the engine.

    Returns: | Method success. ( Boolean )

  `getSelectedNodes`()

    This method returns the View selected nodes.

    Returns: | View selected nodes. ( Dictionary )

  `removeProject`(node)

    This method removes the project associated with given node.

    Parameters: | node – Node. ( ProjectNode / DirectoryNode / FileNode )
    Returns: | Method success. ( Boolean )

  `addNewFile`(node)

    This method adds a new file next to given Node associated path.

    Parameters: | node – Node. ( ProjectNode / DirectoryNode / FileNode )
    Returns: | Method success. ( Boolean )

  `addNewDirectory`(node)

    This method adds a new directory next to given Node associated path.

    Parameters: | node – Node. ( ProjectNode / DirectoryNode / FileNode )
    Returns: | Method success. ( Boolean )

  `rename`(node)

    This method renames given Node associated path.

    Parameters: | node – Node. ( ProjectNode / DirectoryNode / FileNode )
    Returns: | Method success. ( Boolean )

  `delete`(node)

    This method deletes given Node associated path.

    Parameters: | node – Node. ( ProjectNode / DirectoryNode / FileNode )
    Returns: | Method success. ( Boolean )

### Navigation

- index
- modules |
- next |
- previous |
- Umbra 1.0.8 documentation »
- 4. Api »